@@ -3,7 +3,7 @@ import cv2 as cv
 from . import Point
 from . import DetectedArea
 from .DetectedArea import DetectedFace
-from .helperFunctions import *
+from .HelperFunctions import *
 import numpy as np
 
 
